@@ -9,7 +9,7 @@ from ConfigParser import SafeConfigParser
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 
-version = "2.0-1"
+version = "2.1-0"
 trackingEnabled = True
 stopTracking = True
 stopWhenIdle = False
@@ -225,7 +225,7 @@ class Window(object):
         self.window.connect("delete_event", gtk.main_quit, None)
         
         self.labelWidget = gtk.Label("Widget options:")
-        self.labelServer = gtk.Label("Server options:")
+        self.labelServer = gtk.Label("OpenSSH options:")
         self.labelWifiPM = gtk.Label("Wifi PM options:")
     
         self.buttonTrackingEnabled = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
@@ -307,11 +307,11 @@ class Window(object):
         
         if configReverseOrder:
             self.pack_startWifiPMButtons()
-            self.pack_startServerButtons()
+            self.pack_startOpenSSHButtons()
             self.pack_startWidgetButtons()
         else:
             self.pack_startWidgetButtons()
-            self.pack_startServerButtons()
+            self.pack_startOpenSSHButtons()
             self.pack_startWifiPMButtons()
         
         areaScrolling = hildon.PannableArea()
@@ -426,8 +426,6 @@ class Window(object):
         self.vbox.pack_start(self.labelWidget, False, False, 8)
         self.vbox.pack_start(self.buttonTrackingEnabled, False, False, 0)
         self.vbox.pack_start(self.buttonStopTracking, False, False, 0)
-        self.vbox.pack_start(self.buttonStopWhenIdle, False, False, 0)
-        self.vbox.pack_start(self.buttonStopAfterMinutes, False, False, 0)
         self.vbox.pack_start(self.buttonShowConnected, False, False, 0)
         self.vbox.pack_start(self.buttonConnectedIcon, False, False, 0)
         self.vbox.pack_start(self.buttonConfirm, False, False, 0)
@@ -435,9 +433,11 @@ class Window(object):
         self.vbox.pack_start(self.buttonShowSettings, False, False, 0)
         self.vbox.pack_start(self.buttonWifiPMIcon, False, False, 0)
     
-    def pack_startServerButtons(self):
+    def pack_startOpenSSHButtons(self):
         self.vbox.pack_start(self.labelServer, False, False, 8)
         self.vbox.pack_start(self.buttonAutostart, False, False, 0)
+        self.vbox.pack_start(self.buttonStopWhenIdle, False, False, 0)
+        self.vbox.pack_start(self.buttonStopAfterMinutes, False, False, 0)
         
     def pack_startWifiPMButtons(self):
         self.vbox.pack_start(self.labelWifiPM, False, False, 8)
@@ -450,8 +450,6 @@ class Window(object):
         self.vbox.remove(self.labelWidget)
         self.vbox.remove(self.buttonTrackingEnabled)
         self.vbox.remove(self.buttonStopTracking)
-        self.vbox.remove(self.buttonStopWhenIdle)
-        self.vbox.remove(self.buttonStopAfterMinutes)
         self.vbox.remove(self.buttonShowConnected)
         self.vbox.remove(self.buttonConnectedIcon)
         self.vbox.remove(self.buttonConfirm)
@@ -459,9 +457,11 @@ class Window(object):
         self.vbox.remove(self.buttonShowSettings)
         self.vbox.remove(self.buttonWifiPMIcon)
     
-    def removeServerButtons(self):
+    def removeOpenSSHButtons(self):
         self.vbox.remove(self.labelServer)
         self.vbox.remove(self.buttonAutostart)
+        self.vbox.remove(self.buttonStopWhenIdle)
+        self.vbox.remove(self.buttonStopAfterMinutes)
         
     def removeWifiPMButtons(self):
         self.vbox.remove(self.labelWifiPM)
@@ -724,14 +724,14 @@ class Window(object):
     def reverse_clicked(self, dummy):
         global configReverseOrder
         configReverseOrder = not configReverseOrder
-        self.removeServerButtons()
+        self.removeOpenSSHButtons()
         if configReverseOrder:
             self.removeWidgetButtons()
-            self.pack_startServerButtons()
+            self.pack_startOpenSSHButtons()
             self.pack_startWidgetButtons()
         else:
             self.removeWifiPMButtons()
-            self.pack_startServerButtons()
+            self.pack_startOpenSSHButtons()
             self.pack_startWifiPMButtons()
         self.parser.set('options', 'configReverseOrder', str(configReverseOrder))
         self.write_config()
